@@ -2,9 +2,11 @@
   mairix - message index builder and finder for maildir folders.
 
  **********************************************************************
- * Copyright (C) Richard P. Curnow  2002,2003,2004,2005,2006,2007
+ * Copyright (C) Richard P. Curnow  2002,2003,2004,2005,2006,2007,2008
  * Copyright (C) Sanjoy Mahajan 2005
  * - mfolder validation code
+ * Copyright (C) James Cameron 2005
+ * Copyright (C) Paul Fox 2006
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -17,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  **********************************************************************
  */
@@ -184,13 +186,15 @@ static void parse_rc_file(char *name)/*{{{*/
     /* open default file */
     struct passwd *pw;
     char *home;
-    pw = getpwuid(getuid());
-    home = pw->pw_dir;
-    if (!pw) {
-      fprintf(stderr, "Cannot lookup passwd entry for this user\n");
-      exit(2);
+    home = getenv("HOME");
+    if (!home) {
+      pw = getpwuid(getuid());
+      if (!pw) {
+        fprintf(stderr, "Cannot determine home directory\n");
+        exit(2);
+      }
+      home = pw->pw_dir;
     }
-    home = pw->pw_dir;
     name = new_array(char, strlen(home) + 12);
     strcpy(name, home);
     strcat(name, "/.mairixrc");
@@ -373,7 +377,7 @@ void report_error(const char *str, const char *filename)/*{{{*/
 static void print_copyright(void)/*{{{*/
 {
   fprintf(stderr,
-          "mairix %s, Copyright (C) 2002-2007 Richard P. Curnow\n"
+          "mairix %s, Copyright (C) 2002-2010 Richard P. Curnow\n"
           "mairix comes with ABSOLUTELY NO WARRANTY.\n"
           "This is free software, and you are welcome to redistribute it\n"
           "under certain conditions; see the GNU General Public License for details.\n\n",
@@ -407,6 +411,7 @@ static void usage(void)/*{{{*/
          "-p           : purge messages that no longer exist\n"
          "-F           : fast scan for maildir and MH folders (no mtime or size checks)\n"
          "-a           : add new matches to match folder (default : clear it first)\n"
+         "-x           : display excerpt of message headers (default : use match folder)\n" 
          "-t           : include all messages in same threads as matching messages\n"
          "-o <mfolder> : override setting of mfolder from mairixrc file\n"
          "-r           : force raw output regardless of mformat setting in mairixrc file\n"
@@ -495,6 +500,10 @@ int main (int argc, char **argv)/*{{{*/
       break;
     } else if (!strcmp(*argv, "-f") || !strcmp(*argv, "--rcfile")) {
       ++argv, --argc;
+      if (!argc) {
+        fprintf(stderr, "No filename given after -f argument\n");
+        exit(1);
+      }
       arg_rc_file_path = *argv;
     } else if (!strcmp(*argv, "-t") || !strcmp(*argv, "--threads")) {
       do_search = 1;
@@ -504,6 +513,10 @@ int main (int argc, char **argv)/*{{{*/
       do_augment = 1;
     } else if (!strcmp(*argv, "-o") || !strcmp(*argv, "--mfolder")) {
       ++argv, --argc;
+      if (!argc) {
+        fprintf(stderr, "No folder name given after -o argument\n");
+        exit(1);
+      }
       arg_mfolder = *argv;
     } else if (!strcmp(*argv, "-p") || !strcmp(*argv, "--purge")) {
       do_purge = 1;
