@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  **********************************************************************
  */
@@ -773,13 +773,20 @@ void build_mbox_lists(struct database *db, const char *folder_base, /*{{{*/
 
   for (i=0; i<n_paths; i++) {
     char *path = paths[i];
-    if (stat(path, &sb) < 0) {
+    if (lstat(path, &sb) < 0) {
       /* can't stat */
     } else {
-      extant_mboxen[n_extant].full_path = new_string(path);
-      extant_mboxen[n_extant].mtime = sb.st_mtime;
-      extant_mboxen[n_extant].size = sb.st_size;
-      n_extant++;
+      if (S_ISLNK(sb.st_mode)) {
+        /* Skip mbox if symlink */
+        if (verbose) {
+          printf("%s is a link - skipping\n", path);
+        }
+      } else {
+        extant_mboxen[n_extant].full_path = new_string(path);
+        extant_mboxen[n_extant].mtime = sb.st_mtime;
+        extant_mboxen[n_extant].size = sb.st_size;
+        n_extant++;
+      }
     }
     free(paths[i]);
   }
