@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  **********************************************************************
  */
@@ -274,6 +274,7 @@ void free_nvp(struct nvp *nvp)/*{{{*/
         free(ne->rhs);
         break;
     }
+    free(ne);
   }
   free(nvp);
 }
