@@ -2,7 +2,7 @@
   mairix - message index builder and finder for maildir folders.
 
  **********************************************************************
- * Copyright (C) Richard P. Curnow  2006
+ * Copyright (C) Richard P. Curnow  2006,2007
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  **********************************************************************
  */
@@ -25,6 +25,7 @@
 
 enum nvp_action {
   GOT_NAMEVALUE,
+  GOT_NAMEVALUE_CONT,
   GOT_NAME,
   GOT_NAME_TRAILING_SPACE,
   GOT_MAJORMINOR,
